@@ -1,12 +1,11 @@
 use strict;
 use warnings;
-use utf8;
 
 package Pod::Spelling;
-our $VERSION = 0.6; # Catch undefined
+our $VERSION = 0.1;
 
 use Pod::POM;
-require Pod::POM::View::TextBasic;
+
 use warnings::register;
 use Carp;
 
@@ -16,30 +15,25 @@ sub new {
 		(ref($_[0])? shift : {@_})
 	);
 
-	# Pod::POM->default_view( 'Pod::POM::View::TextBasic' )
-	# 	or confess $Pod::POM::ERROR;
-
+	Pod::POM->default_view( 'Pod::POM::View::TextBasic' )
+		or confess $Pod::POM::ERROR;
+	
 	my $self = bless {
 		%$args,
 		_parser => Pod::POM->new,
-		_temp_stoplist => [],
 	}, $class;
-	
-	$self->{skip_paths_matching} ||= [];
-
-	$self->{view} ||= 'Pod::POM::View::TextBasic';
 
 	# Allow a single word to be allowed:
-	if ($self->{allow_words} and not ref $self->{allow_words}){
-		$self->{allow_words} = [ $self->{allow_words} ];
-	}
+	if ($self->{allow_words}){
+		$self->{allow_words} = [$self->{allow_words}] if not ref $self->{allow_words};
+	}		
 
-	unless ($self->{not_pod_wordlist}){
+	if ($self->{not_pod_wordlist}){
 		eval { 
 			no warnings;
-			require Pod::Wordlist ;
+			require Pod::Wordlist 
 		};
-		warnings::warnif( $@ ) if $@;
+		warnings::warnif( $@ );
 	}
 	
 	if (ref $self and $self->{import_speller}){
@@ -54,17 +48,16 @@ sub new {
 				last if $self->import_speller( 'Pod::Spelling::'.$mod );
 			}
 		}
+		
 		$self = $self->_init;
 	}
 
-	Carp::confess 'Could not instantiate any spell checker. Do you have Ispell or Aspell installed with dictionaries?'
-		if not $self->{spell_check_callback};
+	Carp::croak 'Could not instantiate any spell checker. Do you have Ispell or Aspell installed with dictionaries?'
+	if not $self->{spell_check_callback};
 
 	return $self;
 }
 
-# Abstract method to be implemented by sub-classes:
-# if AOK, return calling object, otherwise error string.
 sub _init { return $_[0] }
 
 sub import_speller {
@@ -73,7 +66,7 @@ sub import_speller {
 	eval "require $class";	
 
 	if ($@){
-		warnings::warnif($@);
+		warnings:warnif($@);
 		$self->{spell_check_callback} = undef;
 		return undef;
 	}
@@ -103,30 +96,20 @@ sub _clean_text {
 	return '' if not $text;
 	
 	$text =~ s/(\w+::)+\w+/ /gs;	# Remove references to Perl modules
-	$text =~ s/\s+/ /gs;
-	$text =~ s/[()\@,;:"\/.]+/ /gs;		# Remove punctuation
-	$text =~ s/\d+//sg;
-	$text =~ s/["'](\w+)["']/$1/sg;
-	$text =~ s/\b-(\w+)/ $1/sg;
-	$text =~ s/(\w+)-\b/$1 /sg;
+	$text =~ s/[\s]+/ /gs;
+	$text =~ s/[\W]+/ /gs;			# Remove punctuation
 	
-	foreach my $word ( @{$self->{allow_words}} ){
-		next if not defined $word;
-		$text =~ s/\b\Q$word\E\b//sig;
+	foreach my $word (  @{$self->{allow_words}} ){
+		next if not $word;
+		$text =~ s/\b\Q$word\E\b//g;
 	}
 
-	unless (exists $self->{no_pod_wordlist} or exists $self->{no_pod_wordlist}){
-		no warnings 'once';
+	unless (exists $self->{no_pod_wordlist}){
 		foreach my $word (split /\s+/, $text){
 			$word = '' if exists $Pod::Wordlist::Wordlist->{$word};
 		}
 	}
-
-	# Allow words that are joined by underscores but
-	# which were thought errors: easier than parsing
-	# Perl, for now:
-	$text =~ s/(\w+_\w+||_\w+||\w_)//sg;
-
+	
 	return $text;
 }
 
@@ -135,125 +118,36 @@ sub _clean_text {
 # and sets $self->{errors}->[ $line_number-1 ]->[ badly spelt words for this line ]
 sub check_file {
 	my ($self, $path) = @_;
-    my ($packages, @rv);
+    my @rv;
+    
     $self->{errors} = [];
 	
-	foreach my $re (@{ $self->{skip_paths_matching} }){
-		return () if $path =~ $re;
-	}
-
-	# Crude test to allow package names:
-	{
-		# Hope it is not too large.
-		open my $IN, $path or confess "$! - $path";
-		read $IN, my $content, -s $IN;
-		close $IN;
-
-		my @packages = grep {length} $content =~ /^([}{;]+||)\s*package\s+([a-z](?:[\w]+||::)*?)\s*[;{]/img;
-
-		$self->add_allow_words(
-			@packages,				# Whole package names
-			# Parts of package names
-			map {
-				split /::/, $_
-			} @packages
-		);
-	}
-
-	# To support '=for stopwords', we could create yet another parser, 
-	# and reparse the document, but not sure why that would be better
-	# than this:
-
-		
     my $pom = $self->{_parser}->parse_file($path)
     	or confess $self->{_parser}->error();
 
 	my $code = $self->{spell_check_callback};
-	
+    
 	my $line = 0;
-	foreach my $node ($pom->content){
-
-		if ($node->type() =~ /^(begin|for)$/){
-			my $allowed_line = $node->present( $self->{view} );
-			my @stoplist = split /\s/, $allowed_line;
-			$self->_add_temporary_stoplist( @stoplist );
-			next;
-		}
-
-		my $text = $node->present( $self->{view} );
-		$text =~ s/[\n\r\f]+/ /sg;
-
+	foreach my $text ( split/[\n\r\f]+/, scalar $pom->content()) {
 		$text = $self->_clean_text( $text );
 		my @err = $self->$code( $text );
-		
-		ERR:
-		foreach my $err (@err){
-			foreach my $word (grep {length} split /\s+/, $text){
-				if ($word =~ /([\d_-]\Q$err\E|\Q$err\E[\d_-])/sg){
-					$err = undef;
-					next ERR;
-				}
-			}
-			# Check packages
-			eval {
-				require $path;
-				foreach my $p (keys %$packages){
-					eval { import $p };
-					# die "$err is a method in $p"
-					undef $err if $p->can( $err );
-				}
-			};
-		}
-		
-		@err = grep {defined} @err;
-		
-		if (@err){
-			push @rv, @err;
-			$self->{errors}->[$line] = \@err;
-		}
+		push @rv, @err;
+		$self->{errors}->[$line] = \@err;
 		$line ++;
 	}
-
-	$self->_remove_temporary_stoplist;
-
+	
 	return @rv;
 }
 
 sub add_allow_words {
 	my $self = shift;
-	push @{ $self->{allow_words} }, @_ if $#_ > -1;
+	push @{ $self->{allow_words} }, @_ if $#_;
 }
 
-sub skip_paths_matching {
-	my $self = shift;
-	push @{ $self->{skip_paths_matching} }, @_ if $#_ > -1;
-	return @{ $self->{skip_paths_matching} };
-}
-
-sub _add_temporary_stoplist {
-	my ($self, @stoplist) = @_;
-	my $dict = { map {$_=>1} @{$self->{allow_words}} };
-	my @new;
-	foreach my $word (@stoplist){
-		push @new, $word if not exists $dict->{$word};
-	}
-	push @{ $self->{_temp_stoplist} }, \@new;
-	$self->add_allow_words( @new );
-}
-
-sub _remove_temporary_stoplist {
-	my ($self, @stoplist) = @_;
-	return if not scalar @{ $self->{_temp_stoplist} };
-	my $remove = { map {$_=>1} pop @{ $self->{_temp_stoplist} } };
-	my @allowed;
-	foreach my $word (@{ $self->{allow_words} }){
-		push @allowed, $word if not exists $remove->{$word};
-	}
-}
 
 1;
 
-=encoding utf8
+__END__
 
 =head1 NAME
 
@@ -273,18 +167,15 @@ Pod::Spelling - Send POD to a spelling checker
 	my $o = Pod::Spelling->new(
 		allow_words => [qw[ foo bar ]],
 	);
-	$o->skip_paths_matching( qr{*/DBIC} );
 	say 'Spelling errors: ', join ', ', $o->check_file( 'Module.pm' );
 
 =head1 DESCRIPTION
 
 This module provides extensible spell-checking of POD.
 
-At present, it requires either L<Lingua::Ispell> or L<Text::Aspell>,
+At present, it requires either Lingua::Ispell and Text::Aspell,
 one of which  must be installed on your system, with its binaries, 
-unless you plan to use the API to provide your own spell-checker. In
-the latter case, or if binaries are missing from their default locations,
-expect test failures.
+unless you plan to use the API to provide your own spell-checker.
 
 =head1 TEXT NOT SPELL-CHECKED
 
@@ -316,7 +207,7 @@ The name of the module as written in the standard POD manner:
 =item *
 
 Words contained in L<Pod::Wordlist|Pod::Wordlist>, though that can be disabled
-- see the C<no_pod_wordlist>, below.
+- see L<Pod::Spelling|Pod::Spelling> for details.
 
 =back
 	
@@ -362,12 +253,8 @@ represents a line in the file, and thus may be empty if there are no spelling er
 
 =head2 add_allow_words
 
-Add a list of words to the 'allow' list specified at instantiation.
+Add a list of words to the 'allow' list specified at constrution.
 
-=head2 skip_paths_matching
-
-Supply a list of one or more pre-compiled regular expressions to
-avoid parsing directories they match.
 
 =head1 ADDING A SPELL-CHECKER
 
