@@ -3,7 +3,6 @@ use warnings;
 
 package Pod::Spelling::Aspell;
 use base 'Pod::Spelling';
-use Carp;
 no warnings 'redefine';
 
 our $VERSION = 0.1;
@@ -19,7 +18,7 @@ sub _init {
 		
 	$self->{aspell}->check('house');
 	return $self->{aspell}->errstr if $self->{aspell}->errstr;
-	Carp::croak $self if not ref $self;
+	
 	return $self;
 }
 
@@ -34,6 +33,7 @@ sub _spell_check_callback {
 			and not $self->{aspell}->errstr;
 	}
 	
+	
 	return keys %$errors;
 }
 
